import gulp from 'gulp';
import ejs from 'gulp-ejs';
import rename from 'gulp-rename';
import browserSync from 'browser-sync';


const paths = {
  ejs: [
    'src/**/*.ejs', //.ejsと付くファイルまでのパス
    '!src/**/_*.ejs'//_が先頭についているejsファイルは対象外にする
  ],
  watch: {
    ejs: [
      'src/**/*.ejs', //.ejsと付くファイルまでのパスはすべて監視する
    ]
  }
}

function ejsFunc() {
  return gulp.src(paths.ejs)
    .pipe(ejs()) // ejsプラグインの実行
    .pipe(rename({ extname: '.html' })) // 出力ファイルの拡張子を変更
    .pipe(gulp.dest('dist'));
}

function browserSyncFunc(done) {
  const browserSyncOption = {
    port: 8080,
    notify: false,
    server: {
      proxy: '127.0.0.1:3000',
      baseDir: 'dist/',
    },
    startPath: `/`,//特殊な例で確認したいページが、下層にあった場合に使用
    reloadOnRestart: true,
  };
  browserSync.init(browserSyncOption);
  done();
}

function browserReload(done) {
  browserSync.reload();
  done();
}

function watchFunc(done) {
  gulp.watch(paths.watch.ejs, gulp.series(ejsFunc, browserReload)); //ejsが更新されるたびにリロード
  done();
}

gulp.task('default', gulp.series(ejsFunc, browserSyncFunc, watchFunc));
